==> tine20-allinone_2020.08.8.tar.bz2: Timetracker/js/Timetracker-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nLanguage: bg\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "времева рамка"

, "summary"
: "общо"

, "Total Timesheets"
: "Всички нанесни часове"

, "Billable Timesheets"
: "Платими часове"

, "Total Time"
: "Обща сума"

, "Time of Billable Timesheets"
: "Обща сума на платимите часове"

, "Description"
: "Описание"

, "Detail"
: "Детайл"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: ""

, "Export as ODS"
: "Експорт в ODS-формат"

, "Export as CSV"
: "Експорт в CSV-формат"

, "Export as ..."
: ""

, "Timesheet, Timesheets"
: [
  "Работен час"
 ,"Работни часа"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: ""

, "Could not save {0}."
: ""

, "Booking deadline for this Timeaccount has been exceeded."
: ""

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: ""

, "without contract"
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "Единица"

, "Unit Price"
: "Цена на една единица"

, "Factor"
: ""

, "Budget"
: "Бюджет"

, "Status"
: "Статус"

, "closed"
: "затворено"

, "open"
: "отворено"

, "Cleared In"
: "Пресметнат (нанесен) в"

, "Cleared at"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Работните часове са по сметка / заплатими"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Времево конто"
 ,"Времеви конта"

]
, "Number"
: "Номер"

, "Title"
: "Име"

, "Access"
: "Достъп"

, "Permissions"
: "Права за достър"

, "Time Account - Billed"
: ""

, "not yet billed"
: "все още неплатени"

, "to bill"
: "за плащане"

, "billed"
: "платени"

, "Time Account - Status"
: "Времево конто - статус"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Запази собствени"

, "The grant to add Timesheets to this Timeaccount"
: ""

, "View All"
: "Виж всички"

, "The grant to view Timesheets of other users"
: ""

, "Book All"
: "Запази всички"

, "The grant to add Timesheets for other users"
: ""

, "Manage Clearing"
: "Организирай По сметка"

, "The grant to manage clearing of Timesheets"
: ""

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Показва затворени"

, "Timesheets ODS export configuration"
: ""

, "Use this configuration for the timesheet ODS export."
: ""

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: ""

, "last week"
: ""

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Пресметнат (нанесен) в"

, "Billed"
: "Платени"

, "Booking deadline"
: ""

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Сметка (конто)"

, "Time Account (Number - Title)"
: ""

, "Billable"
: "по сметка / заплатими"

, "Cleared"
: "Осчетоводено"

, "Date"
: "Дата"

, "Start time"
: "Начало"

, "End time"
: ""

, "Duration"
: "Продължителност"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "Времевото конто е затворено"

, "Timetracker"
: "Нанасянене на работни часове"

, "Timeaccounts to bill"
: ""

, "Timeaccounts not yet billed"
: ""

, "Timeaccounts already billed"
: ""

, "My Timesheets today"
: ""

, "My Timesheets this week"
: ""

, "My Timesheets last week"
: ""

, "My Timesheets this month"
: ""

, "My Timesheets last month"
: ""

, "Manage timeaccounts"
: "Обработка на времеви конта"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: ""

, "Add timeaccounts"
: ""

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""






, "Timesheet"
: "Работен час"

, "Timeaccount"
: ""

, "Time Account"
: "Времево конто"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Timetracker/js/Timetracker-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nLanguage: bg\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "времева рамка"

, "summary"
: "общо"

, "Total Timesheets"
: "Всички нанесни часове"

, "Billable Timesheets"
: "Платими часове"

, "Total Time"
: "Обща сума"

, "Time of Billable Timesheets"
: "Обща сума на платимите часове"

, "Description"
: "Описание"

, "Detail"
: "Детайл"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: ""

, "Export as ODS"
: "Експорт в ODS-формат"

, "Export as CSV"
: "Експорт в CSV-формат"

, "Export as ..."
: ""

, "Timesheet, Timesheets"
: [
  "Работен час"
 ,"Работни часа"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: ""

, "Could not save {0}."
: ""

, "Booking deadline for this Timeaccount has been exceeded."
: ""

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: ""

, "without contract"
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "Единица"

, "Unit Price"
: "Цена на една единица"

, "Factor"
: ""

, "Budget"
: "Бюджет"

, "Status"
: "Статус"

, "closed"
: "затворено"

, "open"
: "отворено"

, "Cleared In"
: "Пресметнат (нанесен) в"

, "Cleared at"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Работните часове са по сметка / заплатими"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Времево конто"
 ,"Времеви конта"

]
, "Number"
: "Номер"

, "Title"
: "Име"

, "Access"
: "Достъп"

, "Permissions"
: "Права за достър"

, "Time Account - Billed"
: ""

, "not yet billed"
: "все още неплатени"

, "to bill"
: "за плащане"

, "billed"
: "платени"

, "Time Account - Status"
: "Времево конто - статус"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Запази собствени"

, "The grant to add Timesheets to this Timeaccount"
: ""

, "View All"
: "Виж всички"

, "The grant to view Timesheets of other users"
: ""

, "Book All"
: "Запази всички"

, "The grant to add Timesheets for other users"
: ""

, "Manage Clearing"
: "Организирай По сметка"

, "The grant to manage clearing of Timesheets"
: ""

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Показва затворени"

, "Timesheets ODS export configuration"
: ""

, "Use this configuration for the timesheet ODS export."
: ""

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: ""

, "last week"
: ""

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Пресметнат (нанесен) в"

, "Billed"
: "Платени"

, "Booking deadline"
: ""

, "Accounting time factor"
: ""

, "Stream"
: ""

, "hour"
: ""

, "Account"
: "Сметка (конто)"

, "Time Account (Number - Title)"
: ""

, "Project time billable"
: ""

, "Project time billable (combined)"
: ""

, "Billable"
: "по сметка / заплатими"

, "Project time cleared in"
: ""

, "Project time Invoice"
: ""

, "Project time is cleared"
: ""

, "Projecttime cleared (combined)"
: ""

, "Date"
: "Дата"

, "Start time"
: "Начало"

, "End time"
: ""

, "Duration"
: "Продължителност"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Timetracker"
: "Нанасянене на работни часове"

, "My Timesheets today"
: ""

, "My Timesheets this week"
: ""

, "My Timesheets last week"
: ""

, "My Timesheets this month"
: ""

, "My Timesheets last month"
: ""

, "Timeaccounts to bill"
: ""

, "Timeaccounts not yet billed"
: ""

, "Timeaccounts already billed"
: ""

, "Manage timeaccounts"
: "Обработка на времеви конта"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: ""

, "Add timeaccounts"
: ""

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""








, "Timesheet"
: "Работен час"

, "Timeaccount"
: ""

, "Time Account"
: "Времево конто"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
